﻿using APIs.Profiles;
using Autofac;
using Microsoft.AspNetCore.Authentication.JwtBearer;
using Microsoft.IdentityModel.Tokens;
using Microsoft.OpenApi.Models;
using Repositories.IRepository.IBussiness;
using Repositories.Repository.Bussiness;
using Services.Interface;
using Services;
using System.Configuration;
using System.Reflection;
using System.Text;
using APIs.Extensions;
using FluentValidation.AspNetCore;
using Repositories.IRepository.IUnitOfWork;
using Repositories.Repository.UnitOfWork;

namespace APIs
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }
        public IConfiguration Configuration { get; }
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddSqlsugarSetup(Configuration);


            services.AddMemoryCache();
            services.AddControllers()
                .AddNewtonsoftJson(options =>
                {
                    options.SerializerSettings.ReferenceLoopHandling = Newtonsoft.Json.ReferenceLoopHandling.Ignore;
                    options.SerializerSettings.DateFormatString = "yyyy-MM-dd HH:mm:ss";
                });
            // Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
            services.AddEndpointsApiExplorer();
            services.AddAutoMapper(typeof(MapperProfile));
            services.AddSwaggerGen(options =>
            {
            
            });
            services.AddScoped<ISugarUnitOfWork, SugarUnitOfWork>();
            services.AddScoped<IPoliceService, PoliceService>();
            services.AddScoped<ICarService, CarService>();
            services.AddScoped<IEquipmentSizeService, EquipmentSizeService>();
            //services.AddScoped<IEquipmentTypeService, EquipmentTypeService>();
            services.AddScoped<IPoliceRepository, PoliceRepository>();
            services.AddScoped<ICarRepository, CarRepository>();
            services.AddScoped<IEquipmentSizeRepository, EquipmentSizeRepository>();
            services.AddScoped<IEquipmentTypeRepository, EquipmentTypeRepository>();

            services.AddFluentValidation(options =>
            {
                options.RegisterValidatorsFromAssembly(Assembly.GetExecutingAssembly());
            });
            services.AddCors(options =>
            {
                options.AddPolicy("Cors", policy =>
                {
                    policy
                        .AllowAnyOrigin()
                        .AllowAnyHeader()
                        .AllowAnyMethod();
                });
            });

        }

        public void ConfigureContainer(ContainerBuilder builder)
        {
            var basePath = AppContext.BaseDirectory;

        
        }

        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {

            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseSwagger();

            app.UseSwaggerUI(c =>
            {
                c.SwaggerEndpoint("/swagger/v1/swagger.json", "api.core");
            });

            app.UseCors("Cors");

            app.UseHttpsRedirection();

            app.UseStaticFiles();

            app.UseRouting();

            //先开启认证
            app.UseAuthentication();

            //然后是授权中间件
            app.UseAuthorization();

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapControllers();
            });
        }

    }
}
